=====================
 What is z3c.schema?
=====================

z3c.schema provides additional Zope 3 schema fields.

.. toctree::
   :maxdepth: 1

   baseurl
   dateselect
   email
   hostname
   ip
   optchoice
   payments
   regex


.. toctree::
   :maxdepth: 2

   changelog

Development
===========

z3c.schema is hosted at GitHub:

    https://github.com/zopefoundation/z3c.schema/



Project URLs
============

* http://pypi.python.org/pypi/z3c.schema       (PyPI entry and downloads)


====================
 Indices and tables
====================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
